@@ -10,5 +10,7 @@ from .csv2h5 import csv2h5
 from .analyze_rois import analyze_rois
 from .concat_rois import concat_rois
 from .roi_calc_mw import roi_calc_mw
+from .json2tidycsv import json2tidycsv
+from .obtain_grand_m import obtain_grand_m
 
 from .version import __version__, VERSION
