@@ -208,7 +208,7 @@ def analyze_rois(file, room_layout, output_dir, trial_type, span=''):
     if trial_type == 'with_owner':
 
         sort_by_trial = {
-            'No Treatment': 0,
+            'No treatment': 0,
             'First Saline': 1,
             'First Urine': 3,
             'Second Saline': 4,
@@ -218,11 +218,11 @@ def analyze_rois(file, room_layout, output_dir, trial_type, span=''):
     elif trial_type == 'cat_alone':
 
         sort_by_trial = {
-            'Cat Alone (1)': 0,
-            'Cat Alone (2)': 1,
-            'Cat Alone (3)': 3,
-            'Cat Alone (4)': 4,
-            'Cat Alone (5)': 5
+            'Cat alone (1)': 0,
+            'Cat alone (2)': 1,
+            'Cat alone (3)': 3,
+            'Cat alone (4)': 4,
+            'Cat alone (5)': 5
         }
 
     combined_csv = combined_csv.iloc[combined_csv['trial'].map(
