@@ -19,7 +19,7 @@ def concat_rois(directory, output_dir, trial_type):
     for file in files:
 
         cat = Path(file).stem
- 
+
         if trial_type == 'with_owner':
 
             cat = cat[:-16]
@@ -32,17 +32,24 @@ def concat_rois(directory, output_dir, trial_type):
 
         df["cat"] = cat
 
-        df = df[['cat', 'ROI_name', 'trial', 'transitions_per_roi', 'cumulative_time_in_roi_sec', 'avg_time_in_roi_sec', 'avg_vel_in_roi']]
+        df = df[[
+            'cat', 'ROI_name', 'trial', 'transitions_per_roi',
+            'cumulative_time_in_roi_sec', 'avg_time_in_roi_sec',
+            'avg_vel_in_roi'
+        ]]
 
         df.to_csv(file, index=False)
 
-
-    combined_csv = pd.concat([pd.read_csv(f) for f in files ])
+    combined_csv = pd.concat([pd.read_csv(f) for f in files])
 
     if trial_type == 'with_owner':
 
-        combined_csv.to_csv(output_dir + "with_owner_combined_rois.csv", index=False, encoding='utf-8-sig')
+        combined_csv.to_csv(output_dir + "with_owner_combined_rois.csv",
+                            index=False,
+                            encoding='utf-8-sig')
 
     elif trial_type == 'cat_alone':
 
-        combined_csv.to_csv(output_dir + "cat_alone_combined_rois.csv", index=False, encoding='utf-8-sig')
+        combined_csv.to_csv(output_dir + "cat_alone_combined_rois.csv",
+                            index=False,
+                            encoding='utf-8-sig')
